/*
** CONNECT.C - This is the module containing the code for ODBC for
** allocation and connection.
**
*/

//      -       -       -       -       -       -       -       -       -

#include "sample.h"
#include <dos.h>

//      -       -       -       -       -       -       -       -       -

//      CONNECT.C
//
//      SQLC connection functions.

//      -       -       -       -       -       -       -       -       -

//      Allocate an environment (ENV) block.

RETCODE SQL_API SQLAllocEnv(
	HENV FAR * phenv)
{
	LPENV   lpenv;
	HANDLE  henv;

    henv = GlobalAlloc (GMEM_MOVEABLE | GMEM_ZEROINIT, sizeof (ENV));
    if (henv == NULL || (lpenv = (LPENV)GlobalLock (henv)) == NULL)
    {
	*phenv = SQL_NULL_HENV;
	return SQL_ERROR;
    }
	*phenv = (HENV FAR *)lpenv;
	return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

//      Allocate a DBC block.

RETCODE SQL_API SQLAllocConnect(
	LPENV   lpenv,
	HDBC FAR * phdbc)
{
	LPDBC   lpdbc;
	HANDLE  hdbc;

    hdbc = GlobalAlloc (GMEM_MOVEABLE | GMEM_ZEROINIT, sizeof (DBC));
    if (hdbc == NULL || (lpdbc = (LPDBC)GlobalLock (hdbc)) == NULL)
    {
	*phdbc = SQL_NULL_HENV;
	return SQL_ERROR;
    }
	*phdbc = (HDBC FAR *)lpdbc;
	return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

RETCODE SQL_API SQLConnect(
	LPDBC   lpdbc,
	UCHAR FAR *szDSN,
	SWORD   cbDSN,
	UCHAR FAR *szUID,
	SWORD   cbUID,
	UCHAR FAR *szAuthStr,
	SWORD   cbAuthStr)
{
	return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

//  Sample Dialog Proc for SQLDriverConnect.
//      This has to be exported or subtle, yet very rude, things will happen.

BOOL FAR PASCAL FDriverConnectProc(
	HWND    hdlg,
	WORD    wMsg,
	WORD    wParam,
	LONG    lParam)
{
	switch (wMsg) {
	case WM_INITDIALOG:
		return TRUE;

	case WM_COMMAND:
		switch (wParam) {
		case IDOK:

		case IDCANCEL:
	    EndDialog(hdlg, wParam == IDOK);
			return TRUE;
		}
	}
	return FALSE;
}

//      -       -       -       -       -       -       -       -       -

//      This function as its "normal" behavior is supposed to bring up a
//      dialog box if it isn't given enough information via "szConnStrIn".  If
//      it is given enough information, it's supposed to use "szConnStrIn" to
//      establish a database connection.  In either case, it returns a
//      string to the user that is the string that was eventually used to
//      establish the connection.

RETCODE SQL_API SQLDriverConnect(
	LPDBC   lpdbc,
	HWND    hwnd,
	UCHAR FAR *szConnStrIn,
	SWORD   cbConnStrIn,
	UCHAR FAR *szConnStrOut,
	SWORD   cbConnStrOutMax,
	SWORD FAR *pcbConnStrOutMax,
	UWORD fDriverCompletion)
{
	short   iRet;
	BOOL    fPrompt = FALSE;

	if ((szConnStrIn == NULL) || (!cbConnStrIn) ||
		((cbConnStrIn == SQL_NTS) && (!szConnStrIn[0])))
		fPrompt = TRUE;
	else {
	//  Check connection string for completeness
	if (fDriverCompletion == SQL_DRIVER_COMPLETE ||
	    fDriverCompletion == SQL_DRIVER_PROMPT)
		    fPrompt = TRUE;
	}
	if (fPrompt) {
		//
		//      It is not necessary to call "MakeProcInstance" if you
		//      generate a dialog box from a DLL.
		//
		iRet = DialogBox(s_hModule, "EDRIVERCONNECT", hwnd,
			FDriverConnectProc);
		if ((!iRet) || (iRet == -1))
			return SQL_NO_DATA_FOUND;
	}
    return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

RETCODE SQL_API SQLBrowseConnect(
	LPDBC   lpdbc,
	UCHAR FAR *szConnStrIn,
	SWORD   cbConnStrIn,
	UCHAR FAR *szConnStrOut,
	SWORD   cbConnStrOutMax,
	SWORD FAR *pcbConnStrOut)
{
    return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

RETCODE SQL_API SQLDisconnect(
	LPDBC   lpdbc)
{
	return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

RETCODE SQL_API SQLFreeConnect(
	LPDBC   lpdbc)
{
    GlobalUnlock (LOWORD(GlobalHandle (FP_SEG(lpdbc))));
    GlobalFree (LOWORD(GlobalHandle (FP_SEG(lpdbc))));
	return SQL_SUCCESS;
}

//      -       -       -       -       -       -       -       -       -

RETCODE SQL_API SQLFreeEnv(
	LPENV   lpenv)
{
    GlobalUnlock (LOWORD(GlobalHandle (FP_SEG(lpenv))));
    GlobalFree (LOWORD(GlobalHandle (FP_SEG(lpenv))));
	return SQL_SUCCESS;
}
